-- an animated load screen replacement

-- Copyright (c) 2008 Stefan Scheffler

-- Permission is hereby granted, free of charge, to any person
-- obtaining a copy of this software and associated documentation
-- files (the "Software"), to deal in the Software without
-- restriction, including without limitation the rights to use,
-- copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the
-- Software is furnished to do so, subject to the following
-- conditions:

-- The above copyright notice and this permission notice shall be
-- included in all copies or substantial portions of the Software.

-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-- OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-- NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-- HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-- WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-- FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-- OTHER DEALINGS IN THE SOFTWARE.

local gnc = iup.GetNextChild
local gb = iup.GetBrother

local PLUGIN_DIR = "animatedload"
local ANI_DIR = "plugins/"..PLUGIN_DIR.."/ani/"

local hbase = gnc(LoadingDialog)
local progress = gb(gnc(gb(gnc(gb(gb(gnc(gb(gnc(hbase)))))))))
local tip = gb(gb(gb(gnc(gb(gnc(hbase))))))

tip.title = "-"  

progress:detach()
tip:detach()
tip.alignment = "ALEFT"
tip.font = Font.Default
tip.fgcolor = "255 255 255 150"
tip:hide()

-- remove old contents
local child = gnc(hbase)
while child do
	local next = gb(child)
	iup.Destroy(child)
	child = next
end


local bg = iup.label{title="", image="", expand="YES", bgcolor="150 150 150 0 *", size="FULLxFULL"}
local ani = iup.label{title="", image=ANI_DIR.."load_ani_0001.png", expand="YES", bgcolor="255 255 255 255 &"}
local location = iup.label{title="-", font=Font.Huge, fgcolor="100 100 100 110", expand="HORIZONTAL"}
local entering = iup.label{title="Entering ", font=Font.Huge, fgcolor="100 100 100 110", expand="NO"}

-- could add other info into this box
local textbox = iup.hbox{
	iup.fill{size=5},
	iup.vbox{
		iup.fill{size="%70"},
		iup.hbox{entering, location},
		iup.fill{},
		iup.label{title="Tip:", fgcolor="255 255 255 150", alignment="ALEFT"},
		tip,
		iup.fill{size="20"}
	}
}

local tipbox = iup.hbox{
	iup.fill{size="%70"},
	iup.vbox{iup.fill{size="%1"}, iup.label{title="Tip:", fgcolor="255 255 255 150", alignment="ALEFT"}, tip}
}

local zbox = iup.zbox{bg, ani, textbox, all="YES"}

progress.size = "%100x12"
progress.expand = "HORIZONTAL"

local vbase = iup.vbox{zbox, progress}
hbase:append(vbase)

iup.Refresh(textbox)

local ani_timer = Timer()

local function start_ani()
	if ani_timer:IsActive() then
		return
	end

	local image_idx = 1

	local function ani_timer_cb()
		if image_idx > 26 then image_idx = 1 end
		
		ani.image = string.format(ANI_DIR.."load_ani_%04i.png", image_idx)
		image_idx = image_idx + 1
		ani_timer:SetTimeout(100)
	end

	ani.image = ANI_DIR.."load_ani_0001.png"

	ani_timer:SetTimeout(100, ani_timer_cb)
end

local function stop_ani()
	if ani_timer then
		ani_timer:Kill()
	end
end


local animatedload = {}

local current_system

function animatedload:OnEvent(name, data)
	if name == "SECTOR_CHANGED" then
		local new_system = SplitSectorID(data)
		if current_system ~= new_system then
			bg.image = string.format("images/map_%02i.dds", new_system)
		end

		start_ani()
		location.title = LocationStr(data)
		
		FadeControl(bg, 2, 0, 1)
		FadeControl(entering, 2, 0, 110/255)
		FadeControl(location, 2, 0, 110/255)
		
	elseif name == "SHIP_SPAWNED" or name == "ENTERING_STATION" then
		current_system = SplitSectorID(GetCurrentSectorid())
		stop_ani()
		bg.alpha = "0"
		location.alpha = "0"
		entering.alpha = "0"
	end
end

RegisterEvent(animatedload, "SECTOR_CHANGED")
RegisterEvent(animatedload, "SHIP_SPAWNED")
RegisterEvent(animatedload, "ENTERING_STATION")

